/*
 * Copyright 2013 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.annotations;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Placed on a field, allows to indicate this field use the RowBean declaration of its class. Useful when a field is a
 * bean embedded in another bean.
 * <p>
 * In this case, the smallest column value found in its RowBean declaration will be used as a relative position from
 * this tag value.
 * </p>
 * 
 * 
 * @author Olivier Godineau
 * 
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target(value = ElementType.FIELD)
public @interface Embedded {

	/**
	 * Indicates the position in a row from which begin the field representation.
	 * <ul>
	 * There are two ways to indicate the corresponding cell :
	 * <li>as number (0 is the first cell)l</li>
	 * <li>as an Excel cell number( AB = 27th cell)</li>
	 * </ul>
	 */
	String value();

	/**
	 * When the field is an interface, it's necessary to indicate the class from which use its RowBean declaration and
	 * instanciate the field value.
	 */
	Class<?> concreteClass() default java.lang.Object.class;
}
