/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.formatter;

import java.util.Date;
import java.util.Locale;

/**
 * Allows to represent an object as a String.
 * 
 * @author Olivier Godineau
 * 
 * @param <T>
 *            the class the formatter is responsible to transform.
 */
public class Formatter<T> {

	/**
	 * Default implementation based on toString Method of the given t.
	 * 
	 * @param t
	 *            the value to format.
	 * @return the formatted value.
	 */
	public String toString(T t) { // NOPMD by olivier on 28/01/12 14:10
		return (t == null ? null : t.toString());

	}

	/**
	 * Returns a new instance of a formatter specialized in formatting Date as
	 * String.
	 * 
	 * @param pattern
	 *            pattern. Must be a not null and valid Date pattern.
	 * @param locale
	 *            the locale to used in date formatting.
	 * @return the Date formatter.
	 */
	public static Formatter<Date> getDateFormatter(String pattern, Locale locale) {
		if (pattern == null) {
			throw new IllegalArgumentException("Formatter#getDateFormatter pattern argument must be not null");
		}
		if (locale == null) {
			return new DateFormatter(pattern);
		} else {
			return new DateFormatter(pattern, locale);
		}
	}
}
