/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.impl;

import olg.csv.base.Row;
import olg.csv.bean.IBeanProcessor;

/**
 * 
 * Complex property transformer. Typically the case when we need to instanciate
 * a bean from a list of Strings we want to set as a property of our final bean.
 * 
 * @param <B>
 *            bean this property Processor deals with.
 * 
 */
public final class ComplexPropertyProcessor<B> extends AbstractPropertyProcessor<B> {
	/**
	 * the transformer used to product a bean from a list of Strings
	 */
	@SuppressWarnings("rawtypes")
	private final IBeanProcessor transformer;

	/**
	 * 
	 * @param transformer
	 *            the transformer which products the value of the property to
	 *            set
	 * @param beanClass
	 *            the class of the bean to return. Must be not <code>null</code>
	 * @param propertyName
	 *            the name of the property to set. Must be not <code>null</code>
	 */

	ComplexPropertyProcessor(@SuppressWarnings("rawtypes") IBeanProcessor transformer, Class<B> beanClass,
			String propertyName) {
		super();
		this.transformer = transformer;
		this.beanClass = beanClass;
		this.method = olg.csv.bean.Util.identifySetter(beanClass, propertyName);
		if (method == null) {
			throw new IllegalArgumentException("No such setter for " + beanClass.getName() + "." + propertyName
					+ " field");
		}
	}

	public B transform(Row line, B bean) throws olg.csv.bean.parser.ParseException {

		Object field = transformer.transform(line);
		return invoke(field, bean);

	}

}