/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.sample;

import java.io.File;
import java.io.IOException;
import java.io.PrintStream;

import olg.csv.base.IWriter;
import olg.csv.base.WriterException;
import olg.csv.base.csv.CSVSettings;
import olg.csv.base.csv.CSVWriter;
import olg.csv.bean.BeanWriter;
import olg.csv.bean.loader.LoadException;
import olg.csv.bean.sample.model.Person;

public class ExportToCSVFile {
	private static String XML_CONFIG = "writerCfg.xml";
	private static String OUT_FILE = "ExportedPerson.csv";
	private static CSVSettings SETTINGS = new CSVSettings('"', ',').setCharsetName("UTF8").setLineSeparator("\r\n")
			.setWithHeaders(true);

	/**
	 * Try to write some persons into a CSV file. <li>export persons into csv
	 * file by using of writedCfg.xml configuration(bean-writer configuration,
	 * only for writing exposed in resources package )</li> </ul>
	 * 
	 * @param args
	 *            an output directory path may be specified where to create file
	 */
	public static void main(String[] args) {
		PrintStream out = System.out;
		String directory = null;
		if (args.length > 0) {
			directory = args[0];
		}

		File outFile = new File(directory, OUT_FILE);
		File xmlConfigFile = new File(ExportPerson.class.getResource(XML_CONFIG).getFile());

		outFile.delete();
		out.println("CSV EXPORT ");
		out.println("Config File :" + xmlConfigFile.getAbsolutePath());
		out.println("Out file :" + outFile.getAbsolutePath());

		// The really stuff begins now
		try {

			IWriter writer = new CSVWriter(outFile, SETTINGS);
			BeanWriter<Person> oWriter = new BeanWriter<Person>(xmlConfigFile, writer);

			ExportPerson exportPerson = new ExportPerson(oWriter);
			exportPerson.display(out);
			out.println("See " + outFile.getAbsolutePath());
		} catch (IOException e) {
			e.printStackTrace();
		} catch (LoadException e) {
			e.printStackTrace();
		} catch (WriterException e) {
			e.printStackTrace();
		}

	}

}
