/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.sample;

import java.io.File;
import java.io.IOException;
import java.io.PrintStream;

import olg.csv.base.IReader;
import olg.csv.base.ReaderException;
import olg.csv.base.ods.ODSReader;
import olg.csv.base.ods.ODSSettings;
import olg.csv.bean.BeanReader;
import olg.csv.bean.loader.LoadException;
import olg.csv.bean.parser.ParseException;
import olg.csv.bean.sample.model.Person;

public class ImportFromODSFile {
	public final static File XML_CONFIG = new File(ImportFromODSFile.class.getResource("readerCfg.xml").getFile());
	public final static File IN_FILE = new File(ImportFromODSFile.class.getResource("PersontoImport.ods").getFile());
	public final static ODSSettings ODS_SETTINGS = new ODSSettings(0, 4, 6, "C", "L", true);
	/**
	 * import persons from ODS file by using rowBeanCfg.xml file (bean-row XML
	 * type, reader/writer configuration), both exposed in resources package
	 * 
	 * @param args
	 *            unused
	 */
	public static void main(String[] args) {
		PrintStream out = System.out;

		IReader reader = null;

		out.println("IMPORT FROM PersonToImport.ods with readerCfg.xml mapping file (bean-reader XML type)");
		out.println("Import File :" + IN_FILE.getAbsolutePath());
		out.println("Config File :" + XML_CONFIG.getAbsolutePath());

		try {

			reader = new ODSReader(IN_FILE, ODS_SETTINGS);
			BeanReader<Person> oReader = new BeanReader<Person>(XML_CONFIG, reader);
			try {
				out.println("New created Persons from file :");
				while (oReader.hasNext()) {
					try {
						Person person = oReader.next();

						out.println(person.toString());
					} catch (ParseException ex) {
						out.println("Something went wrong on parsing");
						ex.printStackTrace();
					}
				}
			} finally {// Some ReaderException may occur we haven't catched
				oReader.close();
			}
		} catch (IOException e) {

			e.printStackTrace();
		} catch (LoadException e) {

			e.printStackTrace();
		} catch (ReaderException e) {
			e.printStackTrace();
		}

	}

}
