/*
 * Copyright 2013 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.annotations;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Placed on a field allows to specify a Parser.
 * 
 * @see olg.csv.bean.parser.AbstractParser
 * 
 * @author Olivier Godineau
 * 
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target(value = ElementType.FIELD)
public @interface Parser {

	/**
	 * The class of the choosen Parser. By Default, a date Parser class is
	 * choosen for which two params must be specified :
	 * <ul>
	 * <li>
	 * {@link DateProperty#FORMAT}</li>
	 * <li> {@link DateProperty#LOCALE} optional</li>
	 * </ul>
	 * 
	 */
	Class<? extends olg.csv.bean.parser.AbstractParser<?>> value() default olg.csv.bean.parser.impl.DateParser.class;

	/**
	 * Allows to define some properties to the choosen parser. By Default, empty
	 * Param array.
	 */
	Param[] params() default {};
}
