/*
 * Copyright 2013 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.annotation.processor;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import olg.csv.base.Cell;
import olg.csv.base.Row;
import olg.csv.bean.IPropertyProcessor;
import olg.csv.bean.annotation.test.model.TestEmbeddedProcessorBean;
import olg.csv.bean.annotation.test.model.TestEmbeddedProcessorEmbeddedBean;
import olg.csv.bean.annotations.processor.EmbeddedProcessor;
import olg.csv.bean.impl.CellProcessor;
import olg.csv.bean.impl.ComplexPropertyProcessor;

import org.junit.Assert;
import org.junit.Test;

public final class EmbeddedProcessorTest {

	@Test
	public void getReadingProcessorTest() throws NoSuchFieldException {
		Field field = TestEmbeddedProcessorBean.class.getDeclaredField("embeddedBean");

		TestEmbeddedProcessorBean bean = getReadingProcessorTest(field);
		Assert.assertNotNull(bean.getEmbeddedBean());
		TestEmbeddedProcessorEmbeddedBean embeddedBean = bean.getEmbeddedBean();

		Assert.assertEquals("name", embeddedBean.getName());
		Assert.assertEquals("firstname", embeddedBean.getFirstname());

		field = TestEmbeddedProcessorBean.class.getDeclaredField("embeddedConcreteBean");
		bean = getReadingProcessorTest(field);
		Assert.assertNotNull(bean.getEmbeddedConcreteBean());
		embeddedBean = (TestEmbeddedProcessorEmbeddedBean) bean.getEmbeddedConcreteBean();

		Assert.assertEquals("name", embeddedBean.getName());
		Assert.assertEquals("firstname", embeddedBean.getFirstname());

	}

	@Test
	public void getReadingProcessorKOTest() throws NoSuchFieldException {
		EmbeddedProcessor<TestEmbeddedProcessorBean> embeddedProcessor = new EmbeddedProcessor<TestEmbeddedProcessorBean>(
				TestEmbeddedProcessorBean.class);
		// FIRST CASE rang format error
		Field field = TestEmbeddedProcessorBean.class.getDeclaredField("embeddedBeanNoNum");
		List<IPropertyProcessor<TestEmbeddedProcessorBean>> propertyProcessors = new ArrayList<IPropertyProcessor<TestEmbeddedProcessorBean>>();
		Map<Integer, Integer> map = new HashMap<Integer, Integer>();
		boolean retour = embeddedProcessor.getReadingProcessor(10, field, propertyProcessors, map);
		Assert.assertFalse(retour);

		int translate = 10;
		// 2ND CASE setter not found
		field = TestEmbeddedProcessorBean.class.getDeclaredField("embeddedBeanNoAccess");
		propertyProcessors = new ArrayList<IPropertyProcessor<TestEmbeddedProcessorBean>>();
		map = new HashMap<Integer, Integer>();
		retour = embeddedProcessor.getReadingProcessor(translate, field, propertyProcessors, map);
		Assert.assertFalse(retour);
		// 3RD CASE concreteClass is not concret
		field = TestEmbeddedProcessorBean.class.getDeclaredField("embeddedBeanNoConcretClass");
		propertyProcessors = new ArrayList<IPropertyProcessor<TestEmbeddedProcessorBean>>();
		map = new HashMap<Integer, Integer>();
		retour = embeddedProcessor.getReadingProcessor(translate, field, propertyProcessors, map);
		Assert.assertFalse(retour);
		// 4th CASE ConcreteClass type is not a subclass of the field type.
		field = TestEmbeddedProcessorBean.class.getDeclaredField("embeddedBeanTypeConcretClass");
		propertyProcessors = new ArrayList<IPropertyProcessor<TestEmbeddedProcessorBean>>();
		map = new HashMap<Integer, Integer>();
		retour = embeddedProcessor.getReadingProcessor(translate, field, propertyProcessors, map);
		Assert.assertFalse(retour);

	}

	@Test
	public void getWritingProcessorTest() throws NoSuchFieldException {
		Field field = TestEmbeddedProcessorBean.class.getDeclaredField("embeddedBean");
		getWritingProcessorTest(field);

		field = TestEmbeddedProcessorBean.class.getDeclaredField("embeddedConcreteBean");
		getWritingProcessorTest(field);

	}
	@Test
	public void getWritingProcessorKOTest() throws NoSuchFieldException {
		EmbeddedProcessor<TestEmbeddedProcessorBean> embeddedProcessor = new EmbeddedProcessor<TestEmbeddedProcessorBean>(
				TestEmbeddedProcessorBean.class);
		// FIRST CASE rang format error
		Field field = TestEmbeddedProcessorBean.class.getDeclaredField("embeddedBeanNoNum");
		Map<Integer, List<CellProcessor<TestEmbeddedProcessorBean>>> map = new HashMap<Integer, List<CellProcessor<TestEmbeddedProcessorBean>>>();
		boolean retour = embeddedProcessor.getWritingProcessor(field, map);
		Assert.assertFalse(retour);
		// 2ND CASE setter not found

		field = TestEmbeddedProcessorBean.class.getDeclaredField("embeddedBeanNoAccess");
		map = new HashMap<Integer, List<CellProcessor<TestEmbeddedProcessorBean>>>();
		retour = embeddedProcessor.getWritingProcessor(field, map);
		Assert.assertFalse(retour);
		// 3RD CASE concreteClass is not concret
		field = TestEmbeddedProcessorBean.class.getDeclaredField("embeddedBeanNoConcretClass");
		map = new HashMap<Integer, List<CellProcessor<TestEmbeddedProcessorBean>>>();
		retour = embeddedProcessor.getWritingProcessor(field, map);
		Assert.assertFalse(retour);
		// 4th CASE ConcreteClass type is not a subclass of the field type.
		field = TestEmbeddedProcessorBean.class.getDeclaredField("embeddedBeanTypeConcretClass");
		map = new HashMap<Integer, List<CellProcessor<TestEmbeddedProcessorBean>>>();
		retour = embeddedProcessor.getWritingProcessor(field, map);
		Assert.assertFalse(retour);

	}
	private TestEmbeddedProcessorBean getReadingProcessorTest(Field field) {
		EmbeddedProcessor<TestEmbeddedProcessorBean> embeddedProcessor = new EmbeddedProcessor<TestEmbeddedProcessorBean>(
				TestEmbeddedProcessorBean.class);
		TestEmbeddedProcessorBean bean = new TestEmbeddedProcessorBean();
		List<Cell> cells = new ArrayList<Cell>();
		Cell nameCell = new Cell(11, "name");
		Cell firstNameCell = new Cell(12, "firstname");
		cells.add(nameCell);
		cells.add(firstNameCell);
		Row row = new Row(1, cells, 13);

		List<IPropertyProcessor<TestEmbeddedProcessorBean>> propertyProcessors = new ArrayList<IPropertyProcessor<TestEmbeddedProcessorBean>>();
		Map<Integer, Integer> map = new HashMap<Integer, Integer>();

		boolean retour = embeddedProcessor.getReadingProcessor(10, field, propertyProcessors, map);

		Assert.assertTrue(retour);
		Assert.assertEquals(1, propertyProcessors.size());
		Assert.assertFalse(map.isEmpty());
		Assert.assertEquals(Integer.valueOf(1), map.get(nameCell.getNum()));
		Assert.assertEquals(Integer.valueOf(1), map.get(firstNameCell.getNum()));

		IPropertyProcessor<TestEmbeddedProcessorBean> processor = propertyProcessors.iterator().next();
		Assert.assertTrue(processor instanceof ComplexPropertyProcessor);
		ComplexPropertyProcessor<TestEmbeddedProcessorBean> complex = (ComplexPropertyProcessor<TestEmbeddedProcessorBean>) processor;
		Assert.assertEquals(TestEmbeddedProcessorBean.class, complex.getBeanClass());

		bean = processor.transform(row, bean);
		return bean;

	}

	private void getWritingProcessorTest(Field field) {
		EmbeddedProcessor<TestEmbeddedProcessorBean> embeddedProcessor = new EmbeddedProcessor<TestEmbeddedProcessorBean>(
				TestEmbeddedProcessorBean.class);
		TestEmbeddedProcessorBean bean = new TestEmbeddedProcessorBean();
		TestEmbeddedProcessorEmbeddedBean embeddedBean = new TestEmbeddedProcessorEmbeddedBean();
		embeddedBean.setFirstname("firstname");
		embeddedBean.setName("name");
		bean.setEmbeddedBean(embeddedBean);
		bean.setEmbeddedConcreteBean(embeddedBean);

		Map<Integer, List<CellProcessor<TestEmbeddedProcessorBean>>> map = new HashMap<Integer, List<CellProcessor<TestEmbeddedProcessorBean>>>();
		boolean retour = embeddedProcessor.getWritingProcessor(field, map);

		Assert.assertTrue(retour);
		Assert.assertFalse(map.isEmpty());
		Assert.assertEquals(1, map.get(1).size());
		Assert.assertEquals(1, map.get(2).size());

		CellProcessor<TestEmbeddedProcessorBean> processor = map.get(1).iterator().next();
		Cell cell = processor.transform(bean);
		Assert.assertEquals(1, cell.getNum());
		Assert.assertEquals("name", cell.getValue());

		processor = map.get(2).iterator().next();
		cell = processor.transform(bean);
		Assert.assertEquals(2, cell.getNum());
		Assert.assertEquals("firstname", cell.getValue());

	}
}
