/*
 * Copyright 2013 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.annotation.processor;

import static org.junit.Assert.fail;

import java.lang.reflect.Field;
import java.util.Date;

import olg.csv.bean.annotation.test.model.TestBean;
import olg.csv.bean.annotation.test.model.TestBeanFormatter;
import olg.csv.bean.annotation.test.model.TestFormatterProcessorBean;
import olg.csv.bean.annotations.processor.AnnotationProcessorException;
import olg.csv.bean.annotations.processor.FormatterProcessor;
import olg.csv.bean.formatter.DateFormatter;
import olg.csv.bean.formatter.Formatter;

import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.JUnit4;

@RunWith(JUnit4.class)
public final class FormatterProcessorTest {

	/**
	 * getFormatter Test.
	 * 
	 * @throws NoSuchFieldException
	 * @throws SecurityException
	 */
	@Test
	public void getFormatterTest() throws NoSuchFieldException {
		FormatterProcessor processor = FormatterProcessor.getInstance();
		Field field = TestFormatterProcessorBean.class.getDeclaredField("bean");
		try {
			Formatter<TestBean> formatter = processor.getFormatter(field, TestBean.class);

			Assert.assertNotNull("FormatterProcessor.getFormatter must return a not null formatter", formatter);

			Assert.assertEquals("FormatterProcessor.getFormatter must return a parser with the expected class",
					formatter.getClass(), TestBeanFormatter.class);
			TestBeanFormatter testBean3Formatter = (TestBeanFormatter) formatter;
			Assert.assertEquals("FormatterProcessor.getFormatter must set bool formatter property", true,
					testBean3Formatter.isBool());
			Assert.assertEquals("FormatterProcessor.getFormatter must set string formatter property", "valeur",
					testBean3Formatter.getString());
			Assert.assertEquals("FormatterProcessor.getFormatter must set integer formatter property", 25,
					testBean3Formatter.getInteger());
		} catch (AnnotationProcessorException e) {
			fail(e.getMessage());
			e.printStackTrace();
		}
	}

	/**
	 * Test getFormatter when @Formatter is defined but the formatter class hasn't no args constructor.
	 * 
	 * @throws NoSuchFieldException
	 * @throws SecurityException
	 */
	@Test
	public void getFormatterKOTest() throws NoSuchFieldException {
		FormatterProcessor processor = FormatterProcessor.getInstance();
		Field field = TestFormatterProcessorBean.class.getDeclaredField("bean2");
		try {
			processor.getFormatter(field, TestBean.class);
			fail("FormatterProcessor should not able to instanciate a formatter without no args constructor");
		} catch (AnnotationProcessorException e) {

			e.printStackTrace();
		}
	}

	/**
	 * Test getFormatter when @Formatter not defined.
	 * 
	 * @throws NoSuchFieldException
	 * @throws SecurityException
	 */
	@Test
	public void getFormatterKO2Test() throws NoSuchFieldException {
		FormatterProcessor processor = FormatterProcessor.getInstance();
		Field field = TestFormatterProcessorBean.class.getDeclaredField("bean3");
		try {
			Formatter<TestBean> formatter = processor.getFormatter(field, TestBean.class);
			Assert.assertEquals(Formatter.class, formatter.getClass());
		} catch (AnnotationProcessorException e) {
			fail(e.getMessage());
			e.printStackTrace();
		}
	}

	/**
	 * Test getFormatter when @Formatter is defined and specifies a DateFormatter.
	 * 
	 * @throws NoSuchFieldException
	 * @throws SecurityException
	 */
	@Test
	public void getDateFormatterTest() throws NoSuchFieldException {
		FormatterProcessor processor = FormatterProcessor.getInstance();
		Field field = TestFormatterProcessorBean.class.getDeclaredField("date");
		try {
			Formatter<Date> formatter = processor.getFormatter(field, Date.class);

			Assert.assertNotNull("FormatterProcessor.getFormatter must return a not null formatter", formatter);

			Assert.assertEquals("FormatterProcessor.getFormatter must return a DateFormatter", formatter.getClass(),
					DateFormatter.class);

		} catch (AnnotationProcessorException e) {
			fail(e.getMessage());
			e.printStackTrace();
		}
	}

	/**
	 * Test getFormatter when @Formatter is defined and specifies a Date Formatter without date format parameter.
	 * 
	 * @throws NoSuchFieldException
	 * @throws SecurityException
	 */
	@Test
	public void getDateFormatterKOTest() throws NoSuchFieldException {
		FormatterProcessor processor = FormatterProcessor.getInstance();
		Field field = TestFormatterProcessorBean.class.getDeclaredField("date2");
		try {
			processor.getFormatter(field, Date.class);
			fail("FormatterProcessor should not able to  instanciate a DateFormatter without format param");

		} catch (AnnotationProcessorException e) {

			e.printStackTrace();
		}
	}

}
