/*
 * Copyright 2013 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.annotation.processor;

import static org.junit.Assert.fail;

import java.lang.reflect.Field;
import java.util.Date;

import olg.csv.bean.annotation.test.model.TestBean;
import olg.csv.bean.annotation.test.model.TestBeanParser;
import olg.csv.bean.annotation.test.model.TestParserProcessorBean;
import olg.csv.bean.annotations.processor.AnnotationProcessorException;
import olg.csv.bean.annotations.processor.ParserProcessor;
import olg.csv.bean.parser.AbstractParser;
import olg.csv.bean.parser.impl.DateParser;

import org.junit.Assert;
import org.junit.Test;

public final class ParserProcessorTest {

	@Test
	public void getParserTest() throws NoSuchFieldException {
		ParserProcessor processor = ParserProcessor.getInstance();
		Field field = TestParserProcessorBean.class.getDeclaredField("bean");
		try {
			AbstractParser<TestBean> parser = processor.getParser(field, TestBean.class);

			Assert.assertNotNull("ParserProcessor.getParser must return a not null parser", parser);

			Assert.assertEquals("ParserProcessor.getParser must return a parser with the expected class",
					parser.getClass(), TestBeanParser.class);
			TestBeanParser testBean3Parser = (TestBeanParser) parser;
			Assert.assertEquals("ParserProcessor.getParser must set bool parser property", true,
					testBean3Parser.isBool());
			Assert.assertEquals("ParserProcessor.getParser must set string parser property", "valeur",
					testBean3Parser.getString());
			Assert.assertEquals("ParserProcessor.getParser must set integer parser property", 25,
					testBean3Parser.getInteger());
		} catch (AnnotationProcessorException e) {
			fail(e.getMessage());
			e.printStackTrace();
		}
	}

	/**
	 * Test getParser when @Parser is defined but parser class hasn't no args constructor.
	 * 
	 * @throws NoSuchFieldException
	 * @throws SecurityException
	 */
	@Test
	public void getParserKOTest() throws NoSuchFieldException {
		ParserProcessor processor = ParserProcessor.getInstance();
		Field field = TestParserProcessorBean.class.getDeclaredField("bean2");
		try {
			processor.getParser(field, TestBean.class);
			fail("ParserProcessor should not able to  instanciate a parser without no args constructor");
		} catch (AnnotationProcessorException e) {

			e.printStackTrace();
		}
	}

	/**
	 * Test getParser when @Parser is required and not defined.
	 * 
	 * @throws NoSuchFieldException
	 * @throws SecurityException
	 */
	@Test
	public void getParserKO2Test() throws NoSuchFieldException {
		ParserProcessor processor = ParserProcessor.getInstance();
		Field field = TestParserProcessorBean.class.getDeclaredField("bean3");
		try {
			processor.getParser(field, TestBean.class);
			fail("ParserProcessor should not able to  instanciate a parser without no args constructor");
		} catch (AnnotationProcessorException e) {

			e.printStackTrace();
		}
	}

	/**
	 * Test getParser when @Parser is defined and specifies a DateParser.
	 * 
	 * @throws NoSuchFieldException
	 * @throws SecurityException
	 */
	@Test
	public void getDateParserTest() throws NoSuchFieldException {
		ParserProcessor processor = ParserProcessor.getInstance();
		Field field = TestParserProcessorBean.class.getDeclaredField("date");
		try {
			AbstractParser<Date> parser = processor.getParser(field, Date.class);

			Assert.assertNotNull("ParserProcessor.getParser must return a not null parser", parser);

			Assert.assertEquals("ParserProcessor.getParser must return DateParser parser", parser.getClass(),
					DateParser.class);

		} catch (AnnotationProcessorException e) {
			fail(e.getMessage());
			e.printStackTrace();
		}
	}

	/**
	 * Test getParser when @Parser is defined and specifies a Date parser without date format parameter.
	 * 
	 * @throws NoSuchFieldException
	 * @throws SecurityException
	 */
	@Test
	public void getDateParserKOTest() throws NoSuchFieldException {
		ParserProcessor processor = ParserProcessor.getInstance();
		Field field = TestParserProcessorBean.class.getDeclaredField("date2");
		try {
			processor.getParser(field, Date.class);
			fail("ParserProcessor should not able to  instanciate a Date parser without format param");

		} catch (AnnotationProcessorException e) {

			e.printStackTrace();
		}
	}

}
