/*
 * Copyright 2013 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.annotation.test.model;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

import olg.csv.bean.annotations.Column;
import olg.csv.bean.annotations.DateProperty;
import olg.csv.bean.annotations.Embedded;
import olg.csv.bean.annotations.Formatter;
import olg.csv.bean.annotations.Param;
import olg.csv.bean.annotations.Parser;
import olg.csv.bean.annotations.RowBean;

@RowBean
public class TestRowBeanProcessorBean {
	@Column(value = "C", name = "String")
	private String field1;
	@Column(value = "D", name = "Integer")
	private Integer field2;
	@Embedded("0")
	private TestRowBeanProcessorEmbeddedBean embeddedBean;

	public String getField1() {
		return field1;
	}

	public void setField1(String field1) {
		this.field1 = field1;
	}

	public Integer getField2() {
		return field2;
	}

	public void setField2(Integer field2) {
		this.field2 = field2;
	}

	public TestRowBeanProcessorEmbeddedBean getEmbeddedBean() {
		return embeddedBean;
	}

	public void setEmbeddedBean(TestRowBeanProcessorEmbeddedBean embeddedBean) {
		this.embeddedBean = embeddedBean;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((embeddedBean == null) ? 0 : embeddedBean.hashCode());
		result = prime * result + ((field1 == null) ? 0 : field1.hashCode());
		result = prime * result + ((field2 == null) ? 0 : field2.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		TestRowBeanProcessorBean other = (TestRowBeanProcessorBean) obj;
		if (embeddedBean == null) {
			if (other.embeddedBean != null)
				return false;
		} else if (!embeddedBean.equals(other.embeddedBean))
			return false;
		if (field1 == null) {
			if (other.field1 != null)
				return false;
		} else if (!field1.equals(other.field1))
			return false;
		if (field2 == null) {
			if (other.field2 != null)
				return false;
		} else if (!field2.equals(other.field2))
			return false;
		return true;
	}

	@RowBean
	public static class TestRowBeanProcessorEmbeddedBean {
		@Column(value = "A", name = "Bool")
		private Boolean field1;

		@Column(value = "B", name = "Date")
		@Parser(params = {@Param(name = DateProperty.FORMAT, value = "dd/MM/yyyy")})
		@Formatter(params = {@Param(name = DateProperty.FORMAT, value = "dd/MM/yyyy")})
		private Date field2;

		public Boolean getField1() {
			return field1;
		}

		public void setField1(Boolean field1) {
			this.field1 = field1;
		}

		public Date getField2() {
			return field2;
		}

		public void setField2(Date field2) {
			this.field2 = field2;
		}

		@Override
		public int hashCode() {
			final int prime = 31;
			int result = 1;
			result = prime * result + ((field1 == null) ? 0 : field1.hashCode());
			result = prime * result + ((field2 == null) ? 0 : field2.hashCode());
			return result;
		}

		@Override
		public boolean equals(Object obj) {
			if (this == obj)
				return true;
			if (obj == null)
				return false;
			if (getClass() != obj.getClass())
				return false;
			TestRowBeanProcessorEmbeddedBean other = (TestRowBeanProcessorEmbeddedBean) obj;
			if (field1 == null) {
				if (other.field1 != null)
					return false;
			} else if (!field1.equals(other.field1))
				return false;
			if (field2 == null) {
				if (other.field2 != null)
					return false;
			} else if (!field2.equals(other.field2))
				return false;
			return true;
		}

	}

	public static class TestRowBeanProcessorChildBean extends TestRowBeanProcessorBean {
		@Column(value = "E", name = "Childhood")
		private String childhood;

		public String getChildhood() {
			return childhood;
		}

		public void setChildhood(String childhood) {
			this.childhood = childhood;
		}

		@Override
		public int hashCode() {
			final int prime = 31;
			int result = super.hashCode();
			result = prime * result + ((childhood == null) ? 0 : childhood.hashCode());
			return result;
		}

		@Override
		public boolean equals(Object obj) {
			if (this == obj)
				return true;
			if (!super.equals(obj))
				return false;
			if (getClass() != obj.getClass())
				return false;
			TestRowBeanProcessorChildBean other = (TestRowBeanProcessorChildBean) obj;
			if (childhood == null) {
				if (other.childhood != null)
					return false;
			} else if (!childhood.equals(other.childhood))
				return false;
			return true;
		}

	}
	public static TestRowBeanProcessorChildBean getSample() {
		TestRowBeanProcessorChildBean bean = new TestRowBeanProcessorChildBean();
		bean.setChildhood("Happy");
		bean.setField1("red");
		bean.setField2(101);
		TestRowBeanProcessorEmbeddedBean embeddedBean = new TestRowBeanProcessorEmbeddedBean();
		embeddedBean.setField1(true);
		try {
			embeddedBean.setField2(new SimpleDateFormat("dd/MM/yyyy").parse("06/07/2009"));
		} catch (ParseException e) {

		}
		bean.setEmbeddedBean(embeddedBean);
		return bean;
	}
}
