/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean;

import olg.csv.base.Cell;

/**
 * In writing process, products cells from beans.
 * 
 * @author Olivier Godineau
 * 
 * @param <B>
 *            dedicated bean the processor deals with.
 */
public interface ICellProcessor<B> {

	/**
	 * Product a cell from a bean. Typically, a cell contains a string
	 * representation of a field of the given bean.
	 * 
	 * @param e
	 *            the bean.
	 * @return the cell.
	 */
	Cell transform(B e);

	/**
	 * Provides a header cell.
	 * 
	 * @return the header cell.
	 */
	Cell getHeader();

}