/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.impl;

import olg.csv.base.Row;
import olg.csv.bean.getter.AbstractGetter;
import olg.csv.bean.parser.AbstractParser;

/**
 * 
 * Basic property transformer. Allows to set a property from a string.
 * 
 * @param <B>
 *            dedicated bean the PropertyProcessor deals with.
 * 
 */
public final class PropertyProcessor<B> extends AbstractPropertyProcessor<B> {
	/**
	 * the getter. Allows to extract the property as string from a list of
	 * Strings.
	 */
	private final AbstractGetter getter;

	/**
	 * The parser to product the property to set from a String.
	 */
	@SuppressWarnings("rawtypes")
	private final AbstractParser parser;

	@Override
	public B transform(Row line, B bean) throws olg.csv.bean.parser.ParseException {
		Object object = parser.parse(getter.get(line));

		return invoke(object, bean);

	}

	/**
	 * 
	 * @param getter
	 *            the getter that extracts the string value to parse as a
	 *            property. . Must be not <code>null</code>
	 * @param parser
	 *            the parser that parses the string as a property value. . Must
	 *            be not <code>null</code>
	 * @param propertyName
	 *            the name of the bean property.
	 * @param clazz
	 *            the bean class.
	 */
	PropertyProcessor(AbstractGetter getter, @SuppressWarnings("rawtypes") AbstractParser parser, String propertyName,
			Class<B> clazz) {
		super();
		this.getter = getter;
		this.parser = parser;
		this.beanClass = clazz;
		this.method = olg.csv.bean.Util.identifySetter(clazz, propertyName);

		if (method == null) {
			throw new IllegalArgumentException("No such setter for " + beanClass.getName() + "." + propertyName
					+ " field");
		}

	}

}