/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.loader.filter.impl;

import javax.xml.xpath.XPathExpressionException;

import olg.csv.bean.filter.AbstractStringFilter;
import olg.csv.bean.loader.filter.AbstractFiltreLoader;

import org.w3c.dom.Element;

/**
 * Loader characteristic of Replace filter.
 * 
 * @see AbstractStringFilter#getReplaceFilter(String, String)
 * 
 */
public final class ReplaceFilterLoader extends AbstractFiltreLoader {
	/**
	 * Constructs a loader bound with the replace node.
	 * 
	 * @param successor
	 *            the next filter loader in the loader chain.
	 */
	public ReplaceFilterLoader(AbstractFiltreLoader successor) {
		super("replace", successor);

	}

	@Override
	protected AbstractStringFilter getConcreteFilter(Element node) throws XPathExpressionException {
		return AbstractStringFilter.getReplaceFilter(node.getAttribute("regex"), node.getAttribute("replacement"));
	}
}