/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.loader.filter.impl;

import javax.xml.xpath.XPathExpressionException;

import olg.csv.bean.filter.AbstractStringFilter;
import olg.csv.bean.loader.filter.AbstractFiltreLoader;

import org.w3c.dom.Element;

/**
 * Loader characteristic of Split filter.
 * 
 * @see AbstractStringFilter#getSplitFilter(int, String)
 * 
 */
public final class SplitFilterLoader extends AbstractFiltreLoader {
	/**
	 * Constructs a loader bound with the split node.
	 * 
	 * @param successor
	 *            the next filter loader in the loader chain.
	 */
	public SplitFilterLoader(AbstractFiltreLoader successor) {
		super("split", successor);

	}

	@Override
	protected AbstractStringFilter getConcreteFilter(Element node) throws XPathExpressionException {
		int index = Integer.parseInt(node.getAttribute("n"));

		return AbstractStringFilter.getSplitFilter(index, node.getAttribute("separator"));
	}

}