/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.loader.filter.impl;

import java.util.Locale;

import javax.xml.xpath.XPathExpressionException;

import olg.csv.bean.filter.AbstractStringFilter;
import olg.csv.bean.loader.LoadException;
import olg.csv.bean.loader.Util;
import olg.csv.bean.loader.filter.AbstractFiltreLoader;

import org.w3c.dom.Element;

/**
 * Loader characteristic of upper case first filter.
 * 
 * @see AbstractStringFilter#getUpperFirstFilter(Locale)
 */
public final class UpperFirstFilterLoader extends AbstractFiltreLoader {
	/**
	 * Constructs a loader bound with the upper-first node.
	 * 
	 * @param successor
	 *            the next filter loader in the loader chain.
	 */
	public UpperFirstFilterLoader(AbstractFiltreLoader successor) {
		super("upper-first", successor);

	}

	@Override
	protected AbstractStringFilter getConcreteFilter(Element node) throws XPathExpressionException, LoadException {
		String loc = node.getAttribute("locale");
		Locale locale = Util.getLocale(loc);

		if (!"".equals(loc) && locale == null) {
			throw new LoadException("Locale based on expression[" + loc + "] is not available ");
		}
		return AbstractStringFilter.getUpperFirstFilter(locale);
	}

}