/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.loader.getter.impl;

import javax.xml.xpath.XPathExpressionException;

import olg.csv.bean.getter.AbstractGetter;
import olg.csv.bean.loader.CustomLoader;
import olg.csv.bean.loader.LoadException;
import olg.csv.bean.loader.getter.AbstractGetterLoader;

import org.w3c.dom.Element;

/**
 * The loader used to load a user getter described in XML node. This node must
 * to be conformed to CustomType as defined in our XML schema.
 * 
 * @see CustomLoader
 * 
 */
public final class CustomGetterLoader extends AbstractGetterLoader {

	/**
	 * Constructs a loader bound with the custom node.
	 * 
	 * @param successor
	 *            the next getter loader in the loader chain.
	 */
	public CustomGetterLoader(AbstractGetterLoader successor) {
		super("custom", successor);

	}

	@Override
	protected AbstractGetter getConcreteGetter(Element node, String defaultValue) throws XPathExpressionException,
			LoadException {
		Object object = CustomLoader.getBean(node);
		if (!(object instanceof AbstractGetter)) {
			throw new LoadException(object.getClass() + " must extend " + AbstractGetter.class);
		}
		AbstractGetter getter = (AbstractGetter) object;
		getter.setDefaultValue(defaultValue);
		return getter;
	}

}