/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.loader.parser.impl;

import javax.xml.xpath.XPathExpressionException;

import olg.csv.bean.loader.CustomLoader;
import olg.csv.bean.loader.LoadException;
import olg.csv.bean.loader.parser.AbstractParserLoader;
import olg.csv.bean.parser.AbstractParser;

import org.w3c.dom.Element;

/**
 * Loader used to load user custom parser described in XML node. This node must
 * to be conformed to CustomType as defined in our XML schema.
 * 
 * @see CustomLoader
 * @see AbstractParser
 */
public final class CustomParserLoader extends AbstractParserLoader {
	/**
	 * Constructor.
	 * 
	 * @param successor
	 *            the next parser loader in the loader chain.
	 */
	public CustomParserLoader(AbstractParserLoader successor) {
		super("custom", successor);

	}

	@SuppressWarnings("unchecked")
	@Override
	protected <T> AbstractParser<T> getConcreteParser(Class<T> clazz, Element node) throws XPathExpressionException,
			LoadException {
		Object object = CustomLoader.getBean(node);
		if (!(object instanceof AbstractParser)) {
			throw new LoadException(object.getClass() + " doit étendre la classe " + AbstractParser.class);
		}
		return (AbstractParser<T>) object;
	}
}