/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.base;

import java.util.ArrayList;
import java.util.List;

import junit.framework.TestCase;

public abstract class AbstractReaderTestCase extends TestCase {

	protected void assertEmptyRow(Row row, int expectedNum, boolean skipEmptyCell) {
		assertNotNull("not null row expected",row);
		assertEquals("row num differs from expected",expectedNum, row.getNum());
		assertEquals("Row size differs from expeced",3, row.getSize());
		for (int i = 0; i < 3; i++) {
			Cell cell = row.getCell(i);
			if (skipEmptyCell) {
				assertNull("null cell expected",cell);
			} else {
				assertEmptyCell(cell, i);
			}
		}
	}

	protected void assertEmptyCell(Cell cell, int expectedNum) {
		assertNotNull("not null cell expected",cell);
		assertEquals("cell num differs from expected",expectedNum, cell.getNum());
		assertTrue("empty cell expected",cell.isEmpty());
		assertNull("empty cell value expected",cell.getValue());
	}

	protected void assertEqualsRow(Row expected, Row row) {
		if (expected == null) {
			assertNull("null row expected",row);

		} else {
			assertNotNull("not null row expected",row);
			assertEquals("row num differs from expected", expected.getNum(), row.getNum());
			assertEquals("row size differs from expected", expected.getSize(), row.getSize());
			for (int i = 0; i < row.getSize(); i++) {
				Cell expectedCell = expected.getCell(i);
				Cell cell = row.getCell(i);
				if (expectedCell == null) {
					assertNull("null cell expected",cell);
				} else {
					assertNotNull("not null cell expected", cell);
					assertEquals("cell num differs from expected",expectedCell.getNum(), cell.getNum());
					assertEquals("isEmpty cell method : value returned differs from expected",expectedCell.isEmpty(), cell.isEmpty());
					assertEquals("cell value differs from expected",expectedCell.getValue(), cell.getValue());
				}
			}

		}

	}
	
	protected Row getTemplate(int num, String... values){
		List<Cell> cells = new ArrayList<Cell>();
		int cellNum =0;
		for (String value :values){
			cells.add(new Cell(cellNum++, value)); // NOPMD by olivier on 25/01/12 01:00
		}
		
		return new Row(num,cells ,values.length);
	}

}
