/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.base.csv;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Arrays;

import junit.framework.TestCase;
import olg.csv.base.Cell;
import olg.csv.base.Row;

public class CSVWriterTestCase extends TestCase {

	public void testCharset() throws FileNotFoundException, IOException {
		CSVWriter writer = null;
		File file = new File(this.getClass().getSimpleName() + "-testEncodage-ISO8859-1.csv");
		File fileTest = new File(this.getClass()
				.getResource(CSVReaderTestCase.class.getSimpleName() + "-testEncodage-ISO8859-1.csv").getFile());
		byte[] bytes = new byte[50];
		byte[] bytesTest = new byte[50];

		try {
			writer = new CSVWriter(file, new CSVSettings('"', ';').setForceDelimiter(true).setLineSeparator("\n")
					.setCharsetName("ISO-8859-1"));
			writer.addRow(new Row(1, Arrays.asList(new Cell(0, "àéèçïîôöù")), 1));

		} finally {
			if (writer != null) {
				writer.close();
			}
		}

		int len = getBytes(file, bytes);
		int lenTest = getBytes(fileTest, bytesTest);

		assertEquals("bytes length differs", lenTest, len);
		for (int i = 0; i < len; i++) {
			assertEquals("bytes differs", bytes[i], bytesTest[i]);
		}

	}

	private int getBytes(File file, byte[] bytes) throws FileNotFoundException, IOException {

		FileInputStream stream = null;
		try {
			stream = new FileInputStream(file);
			return stream.read(bytes, 0, 50);
		} finally {
			if (stream != null) {
				stream.close();
			}
		}
	}

}
