/*
 * Copyright 2012 Olivier Godineau
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package olg.csv.bean.loader;

import java.io.File;
import java.io.IOException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import junit.framework.TestCase;

/**
 * PropertyFormatterLoader class TestCase
 * 
 * @author Olivier Godineau
 * 
 */
public class PropertyFormatterLoaderTestCase extends TestCase {
	private final static Logger LOGGER =  LoggerFactory.getLogger(PropertyFormatterLoaderTestCase.class);

	/**
	 * Loading test from a BeanWriter XML type
	 * 
	 * @throws IOException
	 */
	public void testBeanWriterLoad() throws IOException {
		try {

			new CellProcessorLoader().load(new File(Thread.currentThread().getContextClassLoader().getResource(
					"olg/csv/bean/loader/PropertyFormatterLoaderTestCase-testBeanWriterLoad.xml").getFile()));
		} catch (LoadException e) {

			LOGGER.debug("Expected Error on PropertyFormatter loading", e);
			fail(e.toString());
		}
	}

	/**
	 * Loading test from a RowBean XML type.
	 * 
	 * @throws IOException
	 */
	public void testRowBeanLoad() throws IOException {

		try {

			new CellProcessorLoader().load(new File(Thread.currentThread().getContextClassLoader().getResource(
					"olg/csv/bean/loader/PropertyFormatterLoaderTestCase-testRowBeanLoad.xml").getFile()));
		} catch (LoadException e) {

			LOGGER.debug("Expected Error on PropertyFormatter loading", e);
			fail(e.toString());
		}
	}

	/**
	 * Loading test from a BeanReader XML type. This loading must failed.
	 * @throws IOException
	 */
	public void testBeanReaderLoad() throws IOException {

		try {

			new CellProcessorLoader().load(new File(Thread.currentThread().getContextClassLoader().getResource(
					"olg/csv/bean/loader/PropertyFormatterLoaderTestCase-testBeanReaderLoad.xml").getFile()));
			fail("bean-readerTest.xml should have not been loaded by PropertyformatterLoader (only used for writing process)");
		} catch (LoadException e) {
			LOGGER.debug("Error on PropertyFormatter loading", e);
		}
	}
}
